@@ -10,15 +10,17 @@ SQLAlchemy database tables of metadata used by Workspace to manage its local cac
 
 OVERVIEW
 
-Resource : a file containing products, somewhere in the filesystem,
- |         or a resource on a remote system we can access (openDAP etc)
- |_ Product* : product stored in a resource
-     |_ Content* : workspace cache content corresponding to a product,
-     |   |         may be one of many available views (e.g. projections)
-     |   |_ ContentKeyValue* : additional information on content
-     |_ ProductKeyValue* : additional information on product
-     |_ SymbolKeyValue* : if product is derived from other products,
-                          symbol table for that expression is in this kv table
+::
+
+    Resource : a file containing products, somewhere in the filesystem,
+     |         or a resource on a remote system we can access (openDAP etc)
+     |_ Product* : product stored in a resource
+         |_ Content* : workspace cache content corresponding to a product,
+         |   |         may be one of many available views (e.g. projections)
+         |   |_ ContentKeyValue* : additional information on content
+         |_ ProductKeyValue* : additional information on product
+         |_ SymbolKeyValue* : if product is derived from other products,
+                              symbol table for that expression is in this kv table
 
 A typical baseline product will have two content: and overview (lod==0) and a native resolution (lod>0)
 
@@ -38,7 +40,8 @@ import logging
 import os
 import sys
 import unittest
-from collections import MutableMapping, defaultdict
+from collections import defaultdict
+from collections.abc import MutableMapping
 from datetime import datetime
 from functools import reduce
 from uuid import UUID
@@ -886,7 +889,7 @@ def _debug(type, value, tb):
         sys.__excepthook__(type, value, tb)
     else:
         import traceback
-        import pdb
+        import pdb  # noqa
         traceback.print_exception(type, value, tb)
         # …then start the debugger in post-mortem mode.
         pdb.post_mortem(tb)  # more “modern”
@@ -919,9 +922,6 @@ def main():
     levels = [logging.ERROR, logging.WARN, logging.INFO, logging.DEBUG]
     logging.basicConfig(level=levels[min(3, args.verbosity)])
 
-    for pn in args.inputs:
-        pass
-
     return 0
 
 
